//
//  LocationCellTableViewCell.swift
//  MyLocations
//
//  Created by Kary Clements on 1/22/18.
//  Copyright © 2018 Kary Clements. All rights reserved.
//

import UIKit

class LocationCell: UITableViewCell {

    @IBOutlet weak var descriptionLabel: UILabel!
    @IBOutlet weak var addressLabel: UILabel!
    @IBOutlet weak var photoImageView: UIImageView!
    
    override func awakeFromNib() {
        super.awakeFromNib()
        // Initialization code
        let selection = UIView( frame: CGRect.zero )
        selection.backgroundColor = UIColor( white: 1.0, alpha: 0.2 )
        selectedBackgroundView = selection
        
        photoImageView.layer.cornerRadius = photoImageView.bounds.size.width / 2
        photoImageView.clipsToBounds = true
        separatorInset = UIEdgeInsets( top: 0, left: 82, bottom: 0, right: 0 )
        
        //descriptionLabel.backgroundColor = UIColor.purple
        //addressLabel.backgroundColor = UIColor.purple
    }

    override func setSelected(_ selected: Bool, animated: Bool) {
        super.setSelected(selected, animated: animated)

        // Configure the view for the selected state
    }

    func thumbnail( for location: Location ) -> UIImage {
        if location.hasPhoto, let image = location.photoImage {
            return image.resized( withBounds: CGSize( width: 52, height: 52 ))
        } else {
            return UIImage( named: "No Photo" )!
        }
    }
    
    func configure( for location: Location ) {
        if location.locationDescription.isEmpty {
            descriptionLabel.text = "(No Description)"
        } else {
            descriptionLabel.text = location.locationDescription
        }
        
        if let placemark = location.placemark {
            var text = ""
            if let s = placemark.subThoroughfare {
                text += s + " "
            }
            if let s = placemark.thoroughfare {
                text += s + ", "
            }
            if let s = placemark.locality {
                text += s
            }
            addressLabel.text = text
        } else {
            addressLabel.text = String( format: "Lat: %.8f, Long: %.8f", location.latitude, location.longitude )
        }
        photoImageView.image = thumbnail( for: location )
    }
    
}
